@@ -514,7 +514,7 @@ class SaleOpportunityLine(sequence_ordered(), ModelSQL, ModelView):
 
     @classmethod
     def search_rec_name(cls, name, clause):
-        return [('product',) + tuple(clause[1:])]
+        return [('product.rec_name',) + tuple(clause[1:])]
 
 
 class SaleOpportunityReportMixin:
